@@ -1,11 +1,11 @@
-use pnet::packet::Packet;
-use pnet::packet::icmp::echo_request::MutableEchoRequestPacket;
-use pnet::packet::icmp::IcmpTypes;
+use pnet_packet::Packet;
+use pnet_packet::icmp::echo_request::MutableEchoRequestPacket;
+use pnet_packet::icmp::IcmpTypes;
 
 pub fn build_icmp_packet(icmp_packet:&mut MutableEchoRequestPacket) {
     icmp_packet.set_icmp_type(IcmpTypes::EchoRequest);
     icmp_packet.set_sequence_number(rand::random::<u16>());
     icmp_packet.set_identifier(rand::random::<u16>());
-    let icmp_check_sum = pnet::util::checksum(&icmp_packet.packet(), 1);
+    let icmp_check_sum = pnet_packet::util::checksum(&icmp_packet.packet(), 1);
     icmp_packet.set_checksum(icmp_check_sum);
 }
